aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-prp.c
diff options
context:
space:
mode:
authorAnders Broman <anders.broman@ericsson.com>2011-01-21 06:30:55 +0000
committerAnders Broman <anders.broman@ericsson.com>2011-01-21 06:30:55 +0000
commitfe68c6f1d2869cc7c97b7ab71d4e1362741bebb1 (patch)
tree33ed3591de98024054c3de3945c24c05de972aee /epan/dissectors/packet-prp.c
parent531317a1785c4caa5a88f8661f956768ccd59a0d (diff)
From Tobias Klauser:
Fix standard to IEC62439 Part 3 https://bugs.wireshark.org/bugzilla/show_bug.cgi?id=5599 svn path=/trunk/; revision=35605
Diffstat (limited to 'epan/dissectors/packet-prp.c')
-rw-r--r--epan/dissectors/packet-prp.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/epan/dissectors/packet-prp.c b/epan/dissectors/packet-prp.c
index 75cefe0abe..3d3dc895b1 100644
--- a/epan/dissectors/packet-prp.c
+++ b/epan/dissectors/packet-prp.c
@@ -1,5 +1,5 @@
/* packet-prp.c
* Routines for PRP (Parallel Redundancy Protocol; IEC62439 Chapter 6) dissection
* Copyright 2007, Sven Meier <msv[AT]zhwin.ch>
*
* $Id$
@@ -340,7 +340,7 @@ void proto_register_prp(void)
/* Register the protocol name and description */
- proto_prp = proto_register_protocol("Parallel Redundancy Protocol (IEC62439 Chapter 6)",
+ proto_prp = proto_register_protocol("Parallel Redundancy Protocol (IEC62439 Part 3)",
"PRP", "prp");
prp_module = prefs_register_protocol(proto_prp, proto_reg_handoff_prp);
@@ -1,5 +1,5 @@
/* packet-prp.c
- * Routines for PRP (Parallel Redundancy Protocol; IEC62439 Chapter 6) dissection
+ * Routines for PRP (Parallel Redundancy Protocol; IEC62439 Part 3) dissection
* Copyright 2007, Sven Meier <msv[AT]zhwin.ch>
*